@@ -5,9 +5,8 @@ import micromagneticmodel as mm
 
 @uu.inherit_docs
 class DynamicsTerm(mm.abstract.Term):
-    """A parent class for all dynamics terms.
+    """A parent class for all dynamics terms."""
 
-    """
     _container_class = 'Dynamics'
 
     @abc.abstractmethod
