@@ -9,13 +9,21 @@ from .energyterm import EnergyTerm
                               otherwise=df.Field),
                wave=ts.Subset(sample_set={'sin', 'sinc'}, unpack=False),
                f=ts.Scalar(positive=True),
-               t0=ts.Scalar())
+               t0=ts.Scalar(),
+               # time_dependence=ts.Typed(expected_type=callable),
+               tstep=ts.Scalar(positive=True),
+               tcl_strings=ts.Dictionary(
+                   key_descriptor=ts.Subset(
+                       sample_set=('proc', 'energy', 'type', 'script_args',
+                                   'script'), unpack=False),
+                   value_descriptor=ts.Typed(expected_type=str))
+               )
 class Zeeman(EnergyTerm):
-    """Zeeman energy term.
+    r"""Zeeman energy term.
 
     .. math::
 
-        w = -\\mu_{0}M_\\text{s} \\mathbf{m} \\cdot \\mathbf{H}
+        w = -\mu_{0}M_\text{s} \mathbf{m} \cdot \mathbf{H}
 
     Zeeman energy term allows defining time-dependent as well as
     time-independent external magnetic field. If only external magnetic field
@@ -27,15 +35,15 @@ class Zeeman(EnergyTerm):
 
     .. math::
 
-        w = -\\mu_{0}M_\\text{s} \\mathbf{m} \\cdot \\mathbf{H} \\sin[2\\pi
+        w = -\mu_{0}M_\text{s} \mathbf{m} \cdot \mathbf{H} \sin[2\pi
         f(t-t_{0})]
 
     whereas for ``wave='sinc'``, the energy density is:
 
     .. math::
 
-        w = -\\mu_{0}M_\\text{s} \\mathbf{m} \\cdot \\mathbf{H}
-        \\text{sinc}[2\\pi f(t-t_{0})]
+        w = -\mu_{0}M_\text{s} \mathbf{m} \cdot \mathbf{H}
+        \text{sinc}[2\pi f(t-t_{0})]
 
     and ``f`` is a cut-off frequency.
 
@@ -96,7 +104,9 @@ class Zeeman(EnergyTerm):
     ValueError: ...
 
     """
-    _allowed_attributes = ['H', 'wave', 'f', 't0']
+
+    _allowed_attributes = ['H', 'wave', 'f', 't0', 'time_dependence', 'tstep',
+                           'tcl_strings']
 
     @property
     def _reprlatex(self):
